@@ -257,6 +257,22 @@ class R3sponse(object):
 			"error":None,
 	}):
 		return self.ResponseObject(response)
+	def safe_response(self, response={
+			"success":False,
+			"message":None,
+			"error":None,
+	}):
+		if response["success"] in [True, "True", "true"]:
+			message = response["message"]
+			try:  del response["message"]
+			except: a=1
+			try:  del response["error"]
+			except: a=1
+			try:  del response["success"]
+			except: a=1
+			return self.success_response(message, response)
+		else:
+			return self.error_response(response["error"])
 	class ResponseObject(object):
 		def __init__(self, attributes={
 			"success":False,
